@@ -1,6 +1,6 @@
 /*
  * Mar  8, 2000 by Hajimu UMEMOTO <ume@mahoroba.org>
- * $Id: gai.h,v 1.4 2000/05/27 19:16:43 ume Exp $
+ * $Id: gai.h,v 1.9 2004/01/04 10:35:30 ume Exp $
  *
  * This module is besed on ssh-1.2.27-IPv6-1.5 written by
  * KIKUCHI Takahiro <kick@kyoto.wide.ad.jp>
@@ -12,11 +12,14 @@
  * See getaddrinfo.c and getnameinfo.c.
  */
 
+#ifndef _GAI_H_
+#define _GAI_H_
+
 /* for old netdb.h */
-#ifndef EAI_NODATA
-#define EAI_NODATA	1
+#ifndef EAI_SERVICE
 #define EAI_MEMORY	2
 #define EAI_FAMILY	5	/* ai_family not supported */
+#define EAI_NONAME	8	/* hostname nor servname provided, or not known */
 #define EAI_SERVICE	9	/* servname not supported for ai_socktype */
 #endif
 
@@ -24,6 +27,7 @@
 #ifndef AI_PASSIVE
 #define AI_PASSIVE	1
 #define AI_CANONNAME	2
+#define AI_NUMERICHOST	4
 #define NI_NUMERICHOST	2
 #define NI_NAMEREQD	4
 #define NI_NUMERICSERV	8
@@ -38,3 +42,5 @@ struct addrinfo {
 	struct addrinfo *ai_next;	/* next structure in linked list */
 };
 #endif
+
+#endif
